"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getRepoBranches = getRepoBranches;
exports.compareBranches = compareBranches;
exports.getOrgRepoNames = getOrgRepoNames;
exports.getOrgRepos = getOrgRepos;

var _lodash = _interopRequireDefault(require("lodash"));

var _path = _interopRequireDefault(require("path"));

var _debug = _interopRequireDefault(require("debug"));

var _client = require("./client");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const debug = (0, _debug.default)(`${require('../package').name}:${_path.default.basename(__filename)}`);

async function getRepoBranches({
  org,
  repo
}) {
  const gh = (0, _client.getClient)();
  const branchesResponse = await gh.repos.getBranches({
    owner: org,
    repo,
    per_page: 100
  });

  const branches = _lodash.default.map(branchesResponse.data, 'name');

  debug('Loaded branches. Repo: %s, Branches: %o', repo, branches);
  return branches;
}

async function compareBranches({
  org,
  repo
}) {
  const gh = (0, _client.getClient)();
  const {
    data
  } = await gh.repos.compareCommits({
    owner: org,
    repo,
    base: 'master',
    head: 'develop'
  });
  return data;
}

async function getOrgRepoNames(org) {
  const orgRepos = await getOrgRepos(org);
  return _lodash.default.map(orgRepos, 'name');
}

async function getOrgRepos(org) {
  const gh = (0, _client.getClient)();
  const [{
    data: repos1
  }, {
    data: repos2
  }] = await Promise.all([gh.repos.listForOrg({
    org,
    type: 'sources',
    sort: 'pushed',
    per_page: 100,
    page: 1,
    direction: 'desc'
  }), gh.repos.listForOrg({
    org,
    type: 'sources',
    sort: 'pushed',
    per_page: 100,
    page: 2,
    direction: 'desc'
  })]);
  const repos = [...repos1, ...repos2];
  return _lodash.default.uniqBy(repos.filter(repo => !repo.archived), 'name');
}